==> kadaster-gds2-1.3-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstgbresultaat/afgifte/v20130701/BestandenLijstGBType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BestandenLijstGBType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BestandenLijstGBType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701}AfgifteGB" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenLijstGBType", propOrder = {
    "afgifteGB"
})
public class BestandenLijstGBType {

    @XmlElement(name = "AfgifteGB", required = true)
    protected List<AfgifteGBType> afgifteGB;

    /**
     * Gets the value of the afgifteGB property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the afgifteGB property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAfgifteGB().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AfgifteGBType }
     * 
     * 
     */
    public List<AfgifteGBType> getAfgifteGB() {
        if (afgifteGB == null) {
            afgifteGB = new ArrayList<AfgifteGBType>();
        }
        return this.afgifteGB;
    }

}

==> kadaster-gds2-2.0-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstgbresultaat/afgifte/v20130701/BestandenLijstGBType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BestandenLijstGBType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BestandenLijstGBType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbresultaat/afgifte/v20130701}AfgifteGB" maxOccurs="unbounded"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenLijstGBType", propOrder = {
    "afgifteGB"
})
public class BestandenLijstGBType {

    @XmlElement(name = "AfgifteGB", required = true)
    protected List<AfgifteGBType> afgifteGB;

    /**
     * Gets the value of the afgifteGB property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the afgifteGB property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAfgifteGB().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AfgifteGBType }
     * 
     * 
     */
    public List<AfgifteGBType> getAfgifteGB() {
        if (afgifteGB == null) {
            afgifteGB = new ArrayList<AfgifteGBType>();
        }
        return this.afgifteGB;
    }

}
